import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn, slideIn }

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions({
    this.duration = const Duration(milliseconds: 500),
    required this.context,
    required this.child,
    this.animation = AnimationType.normal,
    this.replacement = false,
  }) {
    switch (animation) {
      case AnimationType.normal:
        normalTransition();
        break;
      case AnimationType.fadeIn:
        fadeInTransition();
        break;
      case AnimationType.slideIn:
        slideInTransition();
        break;
    }
  }
  void pushPage(Route route) {
    Navigator.push(context, route);
  }

  void pushReplacementPage(Route route) {
    Navigator.pushReplacement(context, route);
  }

  void normalTransition() {
    final route = MaterialPageRoute(builder: (_) => child);
    (replacement == true) ? pushReplacementPage(route) : pushPage(route);
  }

  void fadeInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (_, __, ___) => child,
      transitionDuration: duration,
      transitionsBuilder: (_, animation, __, child) {
        return FadeTransition(
          opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
            CurvedAnimation(
              parent: animation,
              curve: Curves.easeOut,
            ),
          ),
          child: child,
        );
      },
    );
    (replacement == true) ? pushReplacementPage(route) : pushPage(route);
  }

  void slideInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (_, __, ___) => child,
      transitionDuration: duration,
      transitionsBuilder: (_, animation, __, child) {
        return SlideTransition(
          position: Tween<Offset>(
            begin: const Offset(1, 0),
          ).animate(
            CurvedAnimation(
              parent: animation,
              curve: Curves.easeOut,
            ),
          ),
        );
      },
    );
    (replacement == true) ? pushReplacementPage(route) : pushPage(route);
  }
}
